# Generated by Django 4.2.28

# Django
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("cookie_optin", "0009_add_country_counts"),
    ]

    operations = [
        migrations.AddField(
            model_name="dailyconsentstats",
            name="source_counts",
            field=models.JSONField(
                blank=True,
                default=dict,
                verbose_name="Visitors by traffic source",
            ),
        ),
        migrations.AddField(
            model_name="dailyconsentstats",
            name="referral_counts",
            field=models.JSONField(
                blank=True,
                default=dict,
                verbose_name="Visitors by referral domain",
            ),
        ),
    ]
