# Generated by Django 4.2.28 on 2026-03-03

# Django
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("cookie_optin", "0006_dailyconsentstats"),
    ]

    operations = [
        migrations.AddField(
            model_name="dailyconsentstats",
            name="show_count",
            field=models.PositiveIntegerField(
                default=0,
                verbose_name="Banner displays (visitors)",
            ),
        ),
        migrations.AddField(
            model_name="dailyconsentstats",
            name="no_interaction_count",
            field=models.PositiveIntegerField(
                default=0,
                verbose_name="No interaction (visitors)",
            ),
        ),
    ]
