# Generated by Django 5.2.11 on 2026-02-23

# Django
from django.db import migrations, models


def fill_path_empty(apps, schema_editor):
    Cookie = apps.get_model("cookie_optin", "Cookie")
    Cookie.objects.filter(path__isnull=True).update(path="")


class Migration(migrations.Migration):

    dependencies = [
        ("cookie_optin", "0004_alter_application_options_alter_purpose_options_and_more"),
    ]

    operations = [
        migrations.RunPython(fill_path_empty, migrations.RunPython.noop),
        migrations.AlterField(
            model_name="cookie",
            name="path",
            field=models.CharField(
                blank=True,
                max_length=250,
                null=False,
                verbose_name="Path",
            ),
        ),
    ]
